//
//  WDSpeedTestProtocol.h
//  IWangDingSDK_SCSP
//
//  Created by maoyuxiang on 2019/4/9.
//  Copyright © 2019年 iwangding. All rights reserved.
//

#ifndef WDSpeedTestProtocol_h
#define WDSpeedTestProtocol_h

#import "WDSpeedTestConfig.h"
#import "WDSpeedResult.h"
#import "WDPingResult.h"
#import "WDSpeedFinalResult.h"

@protocol WDSpeedTestDelegate <NSObject>

@required
/**
 该方法在测速准备时被调用，测速准备时会配置策略、节点等
 */
- (void)speedTestWillPrepare;

/**
 该方法在测速准备完成后被调用
 */
- (void)speedTestDidPrepared;

/**
 该方法在测速次数准备完成后被调用

 @param testCounts 测速次数
 @param runType 测速类型
 */
- (void)speedTestDidPreparedWithTestCounts:(NSInteger)testCounts
                                 runType:(WDSpeedTestRunType)runType;

/**
 该方法在测速模块开始时被调用

 @param runType 测速运行的模块类型
 */
- (void)speedTestStartWithRunType:(WDSpeedTestRunType)runType;

/**
 该方法在测速进行过中回吐数据（根据配置的时间间隔）

 @param speed 速率(单位：Byte)
 @param runType 测速运行的模块类型
 */
- (void)speedTestWithSpeed:(NSInteger)speed
                   runType:(WDSpeedTestRunType)runType;

/**
 该方法在测速模块成功后被调用

 @param result 测速结果
 @param runType 测速运行的模块类型
 */
- (void)speedTestSucceed:(id)result
                 runType:(WDSpeedTestRunType)runType;

/**
 该方法在测速失败后被调用

 @param errorCode 错误码
 @param message 错误信息
 */
- (void)speedTestFailedWithCode:(NSInteger)errorCode
                        message:(NSString *)message;

/**
 该方法在测速完成后被调用

 @param result 测速最终结果
 */
- (void)speedTestFinished:(WDSpeedFinalResult *)result;

/**
 该方法在取消测速后被调用
 */
- (void)speedTestCancel;

@optional
/**
 该方法在测速配置参数准备完成后被调用（用于log信息，平时不使用，注意：isLoggable为YES时才触发）
 */
- (void)speedTestDidPreparedConfig:(NSString *)config;

@end


@protocol WDPingDelegate <NSObject>

/**
 开始Ping
 */
- (void)startPing;

/**
 每一次Ping的回调结果（成功）

 @param result Ping的结果对象
 */
- (void)finishedPing:(NSDictionary *)result;


/**
 每一次Ping的回调结果（失败）

 @param message 失败的原因
 */
- (void)failedPing:(NSString *)message;


/**
 所有Ping结束的回调

 @param result Ping的结果
 */
- (void)finishedAllPing:(WDPingResult *)result;

@end

#endif /* WDSpeedTestProtocol_h */
